@@ -9,7 +9,7 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.GridOperationId;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.grid.model.RowRaw;
 import org.gcube.portlets.user.tdwx.client.TabularDataXGridPanel;
 
-import com.allen_sauer.gwt.log.client.Log;
+import com.google.gwt.core.client.GWT;
 import com.google.gwt.event.logical.shared.SelectionEvent;
 import com.google.gwt.event.logical.shared.SelectionHandler;
 import com.google.web.bindery.event.shared.EventBus;
@@ -19,8 +19,8 @@ import com.sencha.gxt.widget.core.client.menu.MenuItem;
 
 /**
  * 
- * @author "Giancarlo Panichi" <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  * 
  *         Defines the context menu of grid
  */
@@ -34,15 +34,17 @@ public class GridContextMenu {
 		this.gridPanel = gridPanel;
 		this.eventBus = eventBus;
 		tableContextMenu = new Menu();
-
-		MenuItem addRowItem = new MenuItem("Add Row");
+		GridContextMenuMessages msgs = GWT.create(GridContextMenuMessages.class);
+		
+		MenuItem addRowItem = new MenuItem(msgs.addRowItem());
 		addRowItem.setId(GridOperationId.ROWADD.toString());
 		addRowItem.setIcon(MainboxResources.INSTANCE.rowInsert());
+		addRowItem.setToolTip(msgs.addRowItemToolTip());
 		addRowItem.addSelectionHandler(new SelectionHandler<Item>() {
 
 			@Override
 			public void onSelection(SelectionEvent<Item> event) {
-				Log.debug("gridPanel is: " + gridPanel);
+				//Log.debug("gridPanel is: " + gridPanel);
 				if (gridPanel != null) {
 					GridContextMenuItemEvent eventGridContextMenu = new GridContextMenuItemEvent(
 							GridOperationId.ROWADD);
@@ -54,14 +56,15 @@ public class GridContextMenu {
 		});
 		tableContextMenu.add(addRowItem);
 
-		MenuItem editRowItem = new MenuItem("Edit Row");
+		MenuItem editRowItem = new MenuItem(msgs.editRowItem());
 		editRowItem.setId(GridOperationId.ROWEDIT.toString());
 		editRowItem.setIcon(MainboxResources.INSTANCE.rowEdit());
+		editRowItem.setToolTip(msgs.editRowItemToolTip());
 		editRowItem.addSelectionHandler(new SelectionHandler<Item>() {
 
 			@Override
 			public void onSelection(SelectionEvent<Item> event) {
-				Log.debug("gridPanel is: " + gridPanel);
+				//Log.debug("gridPanel is: " + gridPanel);
 				if (gridPanel != null) {
 
 					ArrayList<RowRaw> rows = gridPanel.getSelectedRowsAsRaw();
@@ -76,14 +79,15 @@ public class GridContextMenu {
 		});
 		tableContextMenu.add(editRowItem);
 
-		MenuItem deleteRowItem = new MenuItem("Delete Row");
+		MenuItem deleteRowItem = new MenuItem(msgs.deleteRowItem());
 		deleteRowItem.setId(GridOperationId.ROWDELETE.toString());
-		deleteRowItem.setIcon(MainboxResources.INSTANCE.rowRemove());
+		deleteRowItem.setIcon(MainboxResources.INSTANCE.tableRowDeleteSelected());
+		deleteRowItem.setToolTip(msgs.deleteRowItemToolTip());
 		deleteRowItem.addSelectionHandler(new SelectionHandler<Item>() {
 
 			@Override
 			public void onSelection(SelectionEvent<Item> event) {
-				Log.debug("gridPanel is: " + gridPanel);
+				//Log.debug("gridPanel is: " + gridPanel);
 				if (gridPanel != null) {
 					ArrayList<String> rows = gridPanel.getSelectedRowsId();
 					GridContextMenuItemEvent eventGridContextMenu = new GridContextMenuItemEvent(
@@ -96,14 +100,15 @@ public class GridContextMenu {
 		});
 		tableContextMenu.add(deleteRowItem);
 
-		MenuItem replaceRowsItem = new MenuItem("Replace Value");
+		MenuItem replaceRowsItem = new MenuItem(msgs.replaceRowsItem());
 		replaceRowsItem.setId(GridOperationId.REPLACE.toString());
-		replaceRowsItem.setIcon(MainboxResources.INSTANCE.columnReplace());
+		replaceRowsItem.setIcon(MainboxResources.INSTANCE.columnReplaceAll());
+		replaceRowsItem.setToolTip(msgs.replaceRowsItemToolTip());
 		replaceRowsItem.addSelectionHandler(new SelectionHandler<Item>() {
 
 			@Override
 			public void onSelection(SelectionEvent<Item> event) {
-				Log.debug("gridPanel is: " + gridPanel);
+				//Log.debug("gridPanel is: " + gridPanel);
 				if (gridPanel != null) {
 					CellData cellData = gridPanel.getSelectedCell();
 					if (cellData != null) {
